﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using MindFusion.Charting.WinForms;
using MindFusion.Charting.Components;
using MindFusion.Charting;

namespace Tutorial1
{
	public partial class MainForm : Form
	{
		private Dashboard dashboard;

		public MainForm()
		{
			InitializeComponent();
			
			dashboard = new Dashboard();
			dashboard.Dock = DockStyle.Fill;
			Controls.Add(dashboard);
			LayoutBuilder builder = new LayoutBuilder(dashboard);
			
			dashboard.LayoutPanel.Children.Add(new TextComponent()
			{
				Text = "TITLE TEXT",
				FontName = "Times New Roman",
				FontStyle = System.Drawing.FontStyle.Underline,
				FontSize = 20.4,
				HorizontalAlignment = LayoutAlignment.Center
			});
			
			GridPanel grid = new GridPanel();

			Plot2D linePlot = new Plot2D()
			{
				Background = new MindFusion.Drawing.LinearGradientBrush(Color.White,
					Color.FromArgb(224, 224, 224))
					{
						Angle = 90
					}
			};

			Plot2D barPlot = new Plot2D();
			RadarPlot radarPlot = new RadarPlot();
			PolarPlot polarPlot = new PolarPlot();
			Plot3D plot3d1 = new Plot3D();
			Plot3D plot3d2 = new Plot3D();
			Plot3D plot3d3 = new Plot3D();
			Plot2D plot4 = new Plot2D();

			linePlot.XAxis = new Axis();
			linePlot.XAxis.MinValue = 0;
			linePlot.XAxis.MaxValue = 15;
			linePlot.XAxis.Interval = 1;
			linePlot.XAxis.Title = "When?"; 

			linePlot.YAxis = new Axis();
			linePlot.YAxis.MinValue = 0;
			linePlot.YAxis.MaxValue = 35;
			linePlot.YAxis.Interval = 5;
			linePlot.YAxis.Title = "How many thousands?";

			barPlot.XAxis = new Axis();
			barPlot.XAxis.MinValue = -1;
			barPlot.XAxis.MaxValue = 15;
			barPlot.XAxis.Interval = 1;
			barPlot.XAxis.Title = "When?";

			barPlot.YAxis = new Axis();
			barPlot.YAxis.MinValue = 0;
			barPlot.YAxis.MaxValue = 35;
			barPlot.YAxis.Interval = 5;
			barPlot.YAxis.Title = "How many thousands?";

			BarSeries data1 = new BarSeries(
				new List<double>() { 10, 15, 17, 16, 20, 15, 14, 13, 10, 17, 22, 25, 25, 25, 21, 21 },
				null, null, new List<string>() {"nov\n2014","dec\n2014", "jan\n2015", "feb\n2015", "mar\n2015", "apr\n2015", "may\n2015",
					"jun\n2015", "jul\n2015", "aug\n2015", "sep\n2015", "oct\n2015", "nov\n2015", "dec\n2015", "jan\n2016",
					"feb\n2016"})
					{
						Title = "LP Vinyl"
					};
			BarSeries data2 = new BarSeries(
				new List<double>() { 13, 13, 14, 16, 23, 25, 20, 19, 16, 17, 15, 13, 13, 17, 18, 21 },
				null, null)
				{
					Title = "CD"
				};
			BarSeries data3 = new BarSeries(
				new List<double>() { 29, 28, 29, 31, 33, 35, 33, 27, 28, 28, 27, 29, 29, 31, 33, 29 },
				null, null)
				{
					Title = "MP3"
				};

			LineRenderer lineRenderer = new LineRenderer(
				new System.Collections.ObjectModel.ObservableCollection<Series>() { data1, data2, data3 }
			);

			BarRenderer barDataRenderer = new BarRenderer(
				new System.Collections.ObjectModel.ObservableCollection<Series>() { data1, data2, data3 }	
			);

			RadarRenderer radarDataRenderer = new RadarRenderer(
				new System.Collections.ObjectModel.ObservableCollection<Series>() { data1, data2, data3 }
			);

			PieRenderer pieDataRenderer = new PieRenderer(data1, 1);
			BarRenderer3D bar3DDataRenderer = new BarRenderer3D(
				new System.Collections.ObjectModel.ObservableCollection<Series>() { data1, data2, data3 }
			);
			BarRenderer horizontalBar3DDataRenderer = new BarRenderer(
				new System.Collections.ObjectModel.ObservableCollection<Series>() { data1, data2, data3 }
			);
			BarStackRenderer3D barStack3DRenderer = new BarStackRenderer3D(
				new System.Collections.ObjectModel.ObservableCollection<Series>() { data1, data2, data3 }
			);
			BarOverlayRenderer3D barOverlay3DRenderer = new BarOverlayRenderer3D(
				new System.Collections.ObjectModel.ObservableCollection<Series>() { data1, data2, data3 }
			);

			lineRenderer.SeriesStyle = new PerSeriesStyle
			{
				Strokes = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
				},
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
				},
				StrokeThicknesses = new List<double>
				{
					3.0
				}
			};

			barDataRenderer.SeriesStyle = new PerSeriesStyle()
			{
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(206, 0, 0)))
				}
			};

			bar3DDataRenderer.SeriesStyle = new PerSeriesStyle()
			{
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(224, 233, 233))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102)))
				},
				StrokeThicknesses = new List<double> { 1 }
			};

			horizontalBar3DDataRenderer.SeriesStyle = new PerSeriesStyle()
			{
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(224, 233, 233))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102)))
				},
				StrokeThicknesses = new List<double> { 1 }
			};
			horizontalBar3DDataRenderer.HorizontalBars = true;

			barOverlay3DRenderer.SeriesStyle = new PerSeriesStyle()
			{
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(224, 233, 233))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102)))
				},
				StrokeThicknesses = new List<double> { 1 }
			};

			barStack3DRenderer.SeriesStyle = new PerSeriesStyle()
			{
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(224, 233, 233))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(102, 154, 204))),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(150, Color.FromArgb(0, 52, 102)))
				},
				StrokeThicknesses = new List<double> { 1 }
			};
			radarDataRenderer.SeriesStyle = new PerSeriesStyle()
			{
				Strokes = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
				},
				Fills = new List<MindFusion.Drawing.Brush>
				{
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(102, 154, 204)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102)),
					new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0))
				},
				StrokeThicknesses = new List<double> { 5 }
			};
				
			radarDataRenderer.AreaOpacity = 0.2;
			radarPlot.DefaultAxis.MinValue = 0;
			radarPlot.DefaultAxis.MaxValue = 35;
			radarPlot.DefaultAxis.Interval = 5;
			radarPlot.AxisOptions = new RadarAxisOptions(radarPlot.DefaultAxis);
			radarPlot.AxisOptions.ShowSeriesLabels = true;
			radarPlot.AxisOptions.AxisStroke = new MindFusion.Drawing.SolidBrush(Color.LightGray);
			radarPlot.DefaultAxis.Title = "";

			linePlot.SeriesRenderers.Add(lineRenderer);
			barPlot.SeriesRenderers.Add(barDataRenderer);
			radarPlot.SeriesRenderers.Add(radarDataRenderer);
			polarPlot.SeriesRenderers.Add(pieDataRenderer);
			plot3d1.SeriesRenderers.Add(bar3DDataRenderer);
			plot3d2.SeriesRenderers.Add(barStack3DRenderer);
			plot3d3.SeriesRenderers.Add(barOverlay3DRenderer);
			plot4.SeriesRenderers.Add(horizontalBar3DDataRenderer);

			plot3d1.XAxis = new Axis()
			{
				MinValue = 0,
				MaxValue = 5,
				Interval = 1,
				Title = "Months"
			};
			plot3d1.YAxis = new Axis()
			{
				MinValue = 0,
				MaxValue = 40,
				Interval = 5,
				Title = "Thousands"
			};

			plot3d2.XAxis = plot3d3.XAxis = plot3d1.XAxis;
			plot3d2.YAxis = plot3d3.YAxis = plot3d1.YAxis;
			plot3d2.YAxis = new Axis()
			{
				MinValue = 0,
				MaxValue = 100,
				Interval = 5,
				Title = "Thousands"
			};

			plot4.YAxis = new Axis()
			{
				MinValue = 0,
				MaxValue = 4,
				Interval = 1,
				Title = "Months"
			};
			plot4.XAxis = new Axis()
			{
				MinValue = 0,
				MaxValue = 40,
				Interval = 5,
				Title = "Thousands"
			};

			plot4.VerticalScroll = true;

			var xAxisRenderer =  new XAxisRenderer(plot4.XAxis)
			{
				AxisStroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0)),
				AxisStrokeThickness = 3,
				TitleBrush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
				TitleFontName = "Courier New",
				TitleFontSize = 15
			};
			var yAxisRenderer = new YAxisRenderer(plot4.YAxis)
			{
				AxisStroke = new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0)),
				AxisStrokeThickness = 3,
				TitleBrush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
				TitleFontName = "Courier New",
				TitleFontSize = 15
			};

			var panel1 = builder.CreatePlotWithBottomAndLeftAxes(linePlot,
				new XAxisRenderer(linePlot.XAxis)
				{
					LabelsSource = linePlot,
					ShowCoordinates = false,
					LabelFontSize = 6
				},
				new YAxisRenderer(linePlot.YAxis));
			var panel2 = builder.CreatePlotWithBottomAndRightAxes(barPlot,
				new XAxisRenderer(barPlot.XAxis)
				{
					LabelsSource = linePlot,
					ShowCoordinates = false,
					LabelFontSize = 6
				},
				new YAxisRenderer(barPlot.YAxis));
			var panel3 = builder.CreatePlotWithTopAndRightAxes(plot3d1,
				new XAxisRenderer(plot3d1.XAxis)
				{
					ShowCoordinates = false,
					TitleBrush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
					TitleFontName = "Verdana",
					TitleFontSize = 10
				},
				new YAxisRenderer(plot3d1.YAxis)
				{
					TitleBrush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(90, 121, 165)),
					TitleFontName = "Verdana",
					TitleFontSize = 10
				});
			var panel4 = builder.CreatePlotWithTopAndLeftAxes(plot3d2,
				new XAxisRenderer(plot3d2.XAxis)
				{
					TitleBrush = new MindFusion.Drawing.SolidBrush(Color.Blue),
					TitleFontName = "Times New Roman",
					TitleFontSize = 15
				},
				new YAxisRenderer(plot3d2.YAxis)
				{
					TitleBrush = new MindFusion.Drawing.SolidBrush(Color.Blue),
					TitleFontName = "Times New Roman",
					TitleFontSize = 15,
					TitleFontStyle = FontStyle.Bold
				});
			var panel5 = builder.CreatePlotWithTopAndRightAxes(plot3d3,
				new XAxisRenderer(plot3d3.XAxis)
				{
					TitleBrush = new MindFusion.Drawing.SolidBrush(Color.Purple),
					TitleFontName = "Courier New",
					TitleFontSize = 12
				},
				new YAxisRenderer(plot3d3.YAxis)
				{
					TitleBrush = new MindFusion.Drawing.SolidBrush(Color.Purple),
					TitleFontName = "Courier New",
					TitleFontSize = 12
				});
			var panel6 = builder.CreatePlotWithTopAndLeftAxes(plot4, xAxisRenderer,
				yAxisRenderer);

			panel1.Margin = panel2.Margin = panel3.Margin = panel4.Margin =
				panel5.Margin = panel6.Margin = new Margins(5);
			

			grid.Columns.Add(new GridColumn());
			grid.Rows.Add(new GridRow());

			GridPanel miniGrid = new GridPanel();
			miniGrid.Columns.Add(new GridColumn());
			miniGrid.Rows.Add(new GridRow());

			panel1.GridColumn = 0;
			panel1.GridRow = 0;
			panel2.GridColumn = 1;
			panel2.GridRow = 0;
			radarPlot.GridColumn = 0;
			radarPlot.GridRow = 1;

			polarPlot.GridColumn = 0;
			polarPlot.GridRow = 0;
			panel3.GridColumn = 1;
			panel3.GridRow = 0;
			panel4.GridColumn = 0;
			panel4.GridRow = 1;
			panel5.GridColumn = 1;
			panel5.GridRow = 1;
			panel6.GridColumn = 0;
			panel6.GridRow = 0;

			LegendRenderer legend = new LegendRenderer();
			legend.Content.Add(lineRenderer);

			grid.Children.Add(panel1);
			grid.Children.Add(panel2);
			grid.Children.Add(radarPlot);
			grid.Children.Add(miniGrid);

			miniGrid.Children.Add(panel3);
			miniGrid.Children.Add(panel4);
			miniGrid.Children.Add(panel5);
			miniGrid.Children.Add(panel6);
			miniGrid.GridColumn = 1;
			miniGrid.GridRow = 1;		

			dashboard.LayoutPanel.Children.Add(grid);
			dashboard.RootPanel.Children.Add(legend);
		}
	}
}
